@@ -12,6 +12,10 @@ from typing import Any
 
 from pydocextractor.domain.models import Block, BlockType, NormalizedDoc
 
+# Constants for table validation
+MIN_TABLE_LINES = 3  # Need at least header, separator, and one data row
+MIN_TABLE_ROWS = 2  # Need at least header and one data row
+
 # Check pandas availability
 try:
     import pandas as pd
@@ -65,7 +69,7 @@ class TableProfiler:
         table_stats_metadata = {}
         table_index = 0
 
-        for idx, block in enumerate(ndoc.blocks):
+        for _idx, block in enumerate(ndoc.blocks):
             enhanced_blocks.append(block)
 
             # Process TABLE blocks
@@ -86,7 +90,7 @@ class TableProfiler:
                 except Exception as e:
                     # If table profiling fails, continue with next block
                     # Log error in metadata
-                    table_stats_metadata[f"table_{table_index}_error"] = str(e)
+                    table_stats_metadata[f"table_{table_index}_error"] = {"error": str(e)}
                     table_index += 1
 
         # Update metadata with table statistics
@@ -173,7 +177,7 @@ class TableProfiler:
         try:
             lines = [line.strip() for line in markdown.strip().split("\n") if line.strip()]
 
-            if len(lines) < 3:  # Need at least header, separator, and one data row
+            if len(lines) < MIN_TABLE_LINES:  # Need at least header, separator, and one data row
                 return markdown
 
             # Find header and separator
@@ -313,7 +317,7 @@ class TableProfiler:
             # Split into lines and clean
             lines = [line.strip() for line in markdown.strip().split("\n") if line.strip()]
 
-            if len(lines) < 2:
+            if len(lines) < MIN_TABLE_ROWS:
                 return None
 
             # Find header line (first line with |)
